@@ -1,15 +1,12 @@
 mod ptr;
 pub use ptr::ptr;
 
-mod maybe_ptr;
-pub use maybe_ptr::maybe_ptr;
+mod maybe;
+pub use maybe::maybe;
 
 mod string_ptr;
 pub use string_ptr::string_ptr;
 
-mod maybe_string_ptr;
-pub use maybe_string_ptr::maybe_string_ptr;
-
 mod shared_byte_list;
 pub use shared_byte_list::shared_byte_list;
 
@@ -34,9 +31,6 @@ pub use comment::comment;
 mod loc;
 pub use loc::loc;
 
-mod maybe_loc;
-pub use maybe_loc::maybe_loc;
-
 mod magic_comment_kind;
 pub use magic_comment_kind::magic_comment_kind;
 
@@ -67,12 +61,6 @@ pub use decoder::decoder;
 mod token_rewriter;
 pub use token_rewriter::token_rewriter;
 
-mod maybe_decoder;
-pub use maybe_decoder::maybe_decoder;
-
-mod maybe_token_rewriter;
-pub use maybe_token_rewriter::maybe_token_rewriter;
-
 mod parser_options;
 pub use parser_options::parser_options;
 
