@@ -58,18 +58,18 @@ void {fn_attributes} {ns}__node__drop({node_blob}* self_blob);
 }
 
 fn constructors(options: &Options) -> String {
-    map_nodes_to_sigs(options, &helpers::nodes::constructor::sig)
+    map_nodes_to_sigs(options, helpers::nodes::constructor::sig)
 }
 fn variant_predicates(options: &Options) -> String {
-    map_nodes_to_sigs(options, &helpers::nodes::variant_predicate::sig)
+    map_nodes_to_sigs(options, helpers::nodes::variant_predicate::sig)
 }
 fn variant_getters(options: &Options) -> String {
-    map_nodes_to_sigs(options, &helpers::nodes::variant_getter::sig)
+    map_nodes_to_sigs(options, helpers::nodes::variant_getter::sig)
 }
 fn field_getters(options: &Options) -> String {
     nodes()
-        .flat_map(&|node| {
-            node.fields.map(&|field| {
+        .flat_map(|node| {
+            node.fields.map(|field| {
                 format!(
                     "{sig};",
                     sig = helpers::nodes::field_getter::sig(node, field, options)
@@ -80,8 +80,8 @@ fn field_getters(options: &Options) -> String {
 }
 fn field_setters(options: &Options) -> String {
     nodes()
-        .flat_map(&|node| {
-            node.fields.map(&|field| {
+        .flat_map(|node| {
+            node.fields.map(|field| {
                 format!(
                     "{sig};",
                     sig = helpers::nodes::field_setter::sig(node, field, options)
@@ -92,21 +92,24 @@ fn field_setters(options: &Options) -> String {
 }
 fn internal_structs(options: &Options) -> String {
     nodes()
-        .map(&|node| helpers::nodes::internal_struct::definition(node, options))
+        .map(|node| helpers::nodes::internal_struct::definition(node, options))
         .join("\n")
 }
 fn into_variant_fns(options: &Options) -> String {
-    map_nodes_to_sigs(options, &helpers::nodes::into_variant::sig)
+    map_nodes_to_sigs(options, helpers::nodes::into_variant::sig)
 }
 fn into_internal_fns(options: &Options) -> String {
-    map_nodes_to_sigs(options, &helpers::nodes::into_internal::sig)
+    map_nodes_to_sigs(options, helpers::nodes::into_internal::sig)
 }
 fn variant_drop_fns(options: &Options) -> String {
-    map_nodes_to_sigs(options, &helpers::nodes::drop_variant::sig)
+    map_nodes_to_sigs(options, helpers::nodes::drop_variant::sig)
 }
 
-fn map_nodes_to_sigs(options: &Options, sig_fn: &dyn Fn(&Node, &Options) -> String) -> String {
+fn map_nodes_to_sigs<F>(options: &Options, sig_fn: F) -> String
+where
+    F: Fn(&Node, &Options) -> String,
+{
     nodes()
-        .map(&|node| format!("{sig};", sig = sig_fn(node, options)))
+        .map(|node| format!("{sig};", sig = sig_fn(node, options)))
         .join("\n")
 }
