@@ -9,7 +9,7 @@ pub fn name(node: &Node) -> String {
 
 /// Returns definition of the internal struct representing given `node`
 pub fn definition(node: &Node, options: &Options) -> String {
-    let fields = node.fields.map(&|field| {
+    let fields = node.fields.map(|field| {
         format!(
             "{} {};",
             fields::field_type(field, options),
